# DARGALPY
A simple commandline app for automate Dargal T&E report
# Installation
## Using Pip
```bash
  $ pip install dargalpy
```
## Manual
```bash
  $ git clone https://github.com/carlosgeovany/dargalpy
  $ cd dargalpy
  $ python setup.py install
```
# Usage
```bash
$ dargalpy run --filepath <filepath to dargal files>
```